@@ -6,11 +6,12 @@ from aiohttp import hdrs
 from rich import print
 
 from .client import Client
-from .models.bybit import BybitDataStore
-from .models.ftx import FTXDataStore
+from .models import experimental
 from .models.binance import BinanceDataStore
 from .models.bitbank import bitbankDataStore
 from .models.bitmex import BitMEXDataStore
+from .models.bybit import BybitDataStore
+from .models.ftx import FTXDataStore
 from .models.gmocoin import GMOCoinDataStore
 from .typedefs import WsJsonHandler, WsStrHandler
 
@@ -27,6 +28,7 @@ __all__: Tuple[str, ...] = (
     'bitbankDataStore',
     'BitMEXDataStore',
     'GMOCoinDataStore',
+    'experimental',
     'print',
     'print_handler',
 )
