@@ -8,6 +8,7 @@ import aiohttp
 from aiohttp import hdrs
 from aiohttp.client import _RequestContextManager
 
+from .auth import Auth
 from .request import ClientRequest
 from .typedefs import WsJsonHandler, WsStrHandler
 from .ws import ClientWebSocketResponse, ws_run_forever
@@ -21,8 +22,8 @@ class Client:
 
     def __init__(
         self,
-        apis: Union[Dict[str, List[str]], str]={},
-        base_url: str='',
+        apis: Union[Dict[str, List[str]], str] = {},
+        base_url: str = '',
         **kwargs: Any,
     ) -> None:
         self._session = aiohttp.ClientSession(
@@ -42,21 +43,27 @@ class Client:
 
     async def close(self) -> None:
         await self._session.close()
-    
+
     def _request(
         self,
         method: str,
         url: str,
         *,
-        params: Optional[Dict[str, Any]]=None,
-        data: Optional[Dict[str, Any]]=None,
+        params: Optional[Dict[str, Any]] = None,
+        data: Optional[Dict[str, Any]] = None,
+        auth: Optional[Auth] = Auth,
         **kwargs: Any,
     ) -> _RequestContextManager:
+        if method == hdrs.METH_GET and data:
+            logger.warning('Send a GET request, but data argument is set')
+        elif method != hdrs.METH_GET and params:
+            logger.warning(f'Send a {method} request, but params argument is set')
         return self._session.request(
             method=method,
             url=self._base_url + url,
             params=params,
             data=data,
+            auth=auth,
             **kwargs,
         )
 
@@ -65,8 +72,8 @@ class Client:
         method: str,
         url: str,
         *,
-        params: Optional[Mapping[str, str]]=None,
-        data: Any=None,
+        params: Optional[Mapping[str, str]] = None,
+        data: Any = None,
         **kwargs: Any,
     ) -> _RequestContextManager:
         return self._request(method, url, params=params, data=data, **kwargs)
@@ -75,7 +82,7 @@ class Client:
         self,
         url: str,
         *,
-        params: Optional[Mapping[str, str]]=None,
+        params: Optional[Mapping[str, str]] = None,
         **kwargs: Any,
     ) -> _RequestContextManager:
         return self._request(hdrs.METH_GET, url, params=params, **kwargs)
@@ -84,7 +91,7 @@ class Client:
         self,
         url: str,
         *,
-        data: Any=None,
+        data: Any = None,
         **kwargs: Any,
     ) -> _RequestContextManager:
         return self._request(hdrs.METH_POST, url, data=data, **kwargs)
@@ -93,7 +100,7 @@ class Client:
         self,
         url: str,
         *,
-        data: Any=None,
+        data: Any = None,
         **kwargs: Any,
     ) -> _RequestContextManager:
         return self._request(hdrs.METH_PUT, url, data=data, **kwargs)
@@ -102,7 +109,7 @@ class Client:
         self,
         url: str,
         *,
-        data: Any=None,
+        data: Any = None,
         **kwargs: Any,
     ) -> _RequestContextManager:
         return self._request(hdrs.METH_DELETE, url, data=data, **kwargs)
@@ -111,10 +118,10 @@ class Client:
         self,
         url: str,
         *,
-        send_str: Optional[Union[str, List[str]]]=None,
-        send_json: Any=None,
-        hdlr_str: Optional[WsStrHandler]=None,
-        hdlr_json: Optional[WsJsonHandler]=None,
+        send_str: Optional[Union[str, List[str]]] = None,
+        send_json: Any = None,
+        hdlr_str: Optional[WsStrHandler] = None,
+        hdlr_json: Optional[WsJsonHandler] = None,
         **kwargs: Any,
     ) -> asyncio.Task:
         event = asyncio.Event()
