@@ -25,7 +25,7 @@ class DataStore:
         self._data: Dict[uuid.UUID, Item] = {}
         self._index: Dict[int, uuid.UUID] = {}
         self._keys: Tuple[str, ...] = tuple(keys if keys else self._KEYS)
-        self._events: List[asyncio.Event] = []
+        self._events: Dict[asyncio.Event, List[Item]] = {}
         self._insert(data)
         if hasattr(self, '_init'):
             getattr(self, '_init')()
@@ -61,7 +61,8 @@ class DataStore:
                 _id = uuid.uuid4()
                 self._data[_id] = item
             self._sweep_without_key()
-        self._set()
+        # !TODO! This behaviour might be undesirable.
+        self._set(data)
 
     def _update(self, data: List[Item]) -> None:
         if self._keys:
@@ -84,7 +85,8 @@ class DataStore:
                 _id = uuid.uuid4()
                 self._data[_id] = item
             self._sweep_without_key()
-        self._set()
+        # !TODO! This behaviour might be undesirable.
+        self._set(data)
 
     def _delete(self, data: List[Item]) -> None:
         if self._keys:
@@ -98,7 +100,8 @@ class DataStore:
                     if keyhash in self._index:
                         del self._data[self._index[keyhash]]
                         del self._index[keyhash]
-        self._set()
+        # !TODO! This behaviour might be undesirable.
+        self._set(data)
 
     def _clear(self) -> None:
         self._data.clear()
@@ -133,6 +136,20 @@ class DataStore:
                 if keyhash in self._index:
                     return self._data[self._index[keyhash]]
 
+    def _pop(self, item: Item) -> Optional[Item]:
+        if self._keys:
+            try:
+                keyitem = {k: item[k] for k in self._keys}
+            except KeyError:
+                pass
+            else:
+                keyhash = self._hash(keyitem)
+                if keyhash in self._index:
+                    ret = self._data[self._index[keyhash]]
+                    del self._data[self._index[keyhash]]
+                    del self._index[keyhash]
+                    return ret
+
     def find(self, query: Item = {}) -> List[Item]:
         if query:
             return [
@@ -143,21 +160,38 @@ class DataStore:
         else:
             return list(self)
 
-    def _set(self) -> None:
+    def _find_and_delete(self, query: Item = {}) -> List[Item]:
+        if query:
+            ret = [
+                item
+                for item in self
+                if all(k in item and query[k] == item[k] for k in query)
+            ]
+            self._delete(ret)
+            return ret
+        else:
+            ret = list(self)
+            self._clear()
+            return ret
+
+    def _set(self, data: List[Item] = None) -> None:
         for event in self._events:
             event.set()
-        self._events.clear()
+            self._events[event].extend(data)
 
-    async def wait(self) -> None:
+    async def wait(self) -> List[Item]:
         event = asyncio.Event()
-        self._events.append(event)
+        ret = []
+        self._events[event] = ret
         await event.wait()
+        del self._events[event]
+        return ret
 
 
 TDataStore = TypeVar('TDataStore', bound=DataStore)
 
 
-class DataStoreInterface:
+class DataStoreManager:
     def __init__(self) -> None:
         self._stores: Dict[str, DataStore] = {}
         self._events: List[asyncio.Event] = []
